<!DOCTYPE html>
<html>
<head>
    <title>Chat with {{ $user->name }}</title>
    <script src="https://js.pusher.com/7.2/pusher.min.js"></script>
    @vite(['resources/css/app.css', 'resources/js/app.js'])
</head>
<body>
<div id="app">
    <h1>Chat with {{ $user->name }}</h1>
    <div id="messages">
        @foreach ($messages as $message)
            <div>
                <strong>{{ $message->sender_id == auth()->id() ? 'You' : $user->name }}:</strong>
                {{ $message->message }}
            </div>
        @endforeach
    </div>

    <form id="chat-form">
        <input type="hidden" id="receiver_id" value="{{ $user->id }}">
        <textarea id="message" placeholder="Type a message"></textarea>
        <button type="submit">Send</button>
    </form>
</div>

<script>
    const receiverId = document.getElementById('receiver_id').value;

    // Pusher Setup
    const pusher = new Pusher('{{ env('PUSHER_APP_KEY') }}', {
        cluster: '{{ env('PUSHER_APP_CLUSTER') }}',
        encrypted: true,
    });

    const channel = pusher.subscribe('private-chat-' + {{ auth()->id() }});
    channel.bind('message-sent', function(data) {
        const messages = document.getElementById('messages');
        const message = document.createElement('div');
        message.innerHTML = `<strong>${data.sender_id == {{ auth()->id() }} ? 'You' : '{{ $user->name }}'}:</strong> ${data.message}`;
        messages.appendChild(message);
    });

    document.getElementById('chat-form').addEventListener('submit', async function(e) {
        e.preventDefault();
        const message = document.getElementById('message').value;

        await fetch('{{ route('user.send_message') }}', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'X-CSRF-TOKEN': '{{ csrf_token() }}',
            },
            body: JSON.stringify({
                message,
                receiver_id: receiverId,
            }),
        });

        document.getElementById('message').value = '';
    });
</script>
</body>
</html>
